@@ -11,15 +11,15 @@ from __future__ import annotations
 
 import os
 import sys
-import sysconfig
 import warnings
 
-from pathlib import Path
 from collections.abc import Iterator
 
 import pytest
 
 from coverage.files import set_relative_directory
+from coverage.patch import create_pth_files
+
 
 # Pytest will rewrite assertions in test modules, but not elsewhere.
 # This tells pytest to also rewrite assertions in these files:
@@ -30,7 +30,6 @@ pytest.register_assert_rewrite("tests.helpers")
 # $set_env.py: PYTEST_ADDOPTS - Extra arguments to pytest.
 
 pytest_plugins = [
-    "tests.balance_xdist_plugin",
     "tests.select_plugin",
 ]
 
@@ -94,55 +93,13 @@ def force_local_pyc_files() -> None:
     sys.pycache_prefix = None
 
 
-WORKER = os.getenv("PYTEST_XDIST_WORKER", "none")
-
-def pytest_sessionstart() -> None:
-    """Run once at the start of the test session."""
-    warnings.filterwarnings("ignore", r".*no-sysmon")
-    # Only in the main process...
-    if WORKER == "none":
-        # Create a .pth file for measuring subprocess coverage.
-        pth_dir = find_writable_pth_directory()
-        assert pth_dir
-        sub_dir = pth_dir / "subcover.pth"
-        sub_dir.write_text("import coverage; coverage.process_startup()\n", encoding="utf-8")
-        # subcover.pth is deleted by pytest_sessionfinish below.
-
-
-def pytest_sessionfinish() -> None:
-    """Hook the end of a test session, to clean up."""
-    # This is called by each of the workers and by the main process.
-    if WORKER == "none":
-        for pth_dir in possible_pth_dirs():             # pragma: part covered
-            pth_file = pth_dir / "subcover.pth"
-            if pth_file.exists():
-                pth_file.unlink()
-
-
-def possible_pth_dirs() -> Iterator[Path]:
-    """Produce a sequence of directories for trying to write .pth files."""
-    # First look through sys.path, and if we find a .pth file, then it's a good
-    # place to put ours.
-    for pth_dir in map(Path, sys.path):             # pragma: part covered
-        pth_files = list(pth_dir.glob("*.pth"))
-        if pth_files:
-            yield pth_dir
-
-    # If we're still looking, then try the Python library directory.
-    # https://github.com/nedbat/coveragepy/issues/339
-    yield Path(sysconfig.get_path("purelib"))       # pragma: cant happen
-
-
-def find_writable_pth_directory() -> Path | None:
-    """Find a place to write a .pth file."""
-    for pth_dir in possible_pth_dirs():             # pragma: part covered
-        try_it = pth_dir / f"touch_{WORKER}.it"
-        try:
-            try_it.write_text("foo", encoding="utf-8")
-        except OSError:                             # pragma: cant happen
-            continue
-
-        os.remove(try_it)
-        return pth_dir
-
-    return None                                     # pragma: cant happen
+# Give this an underscored name so pylint won't complain when we use the fixture.
+@pytest.fixture(name="_create_pth_file")
+def create_pth_file_fixture() -> Iterator[None]:
+    """Create and clean up a .pth file for tests that need it for subprocesses."""
+    pth_files = create_pth_files()
+    try:
+        yield
+    finally:
+        for p in pth_files:
+            p.unlink()
