@@ -25,7 +25,6 @@ from typing import (
 )
 from collections.abc import Iterable, Iterator
 
-import coverage
 from coverage import env
 from coverage.debug import DebugControl
 from coverage.exceptions import CoverageWarning
@@ -396,12 +395,7 @@ def all_our_source_files() -> Iterator[tuple[Path, str]]:
 
     Produces a stream of (filename, file contents) tuples.
     """
-    cov_dir = Path(coverage.__file__).parent.parent
-    if ".tox" in cov_dir.parts:
-        # We are in a tox-installed environment, look above the .tox dir to
-        # also find the uninstalled source files.
-        cov_dir = Path(os.fspath(cov_dir).partition(".tox")[0])
-
+    cov_dir = Path(__file__).parent.parent
     # To run against all the files in the tox venvs:
     #   for source_file in cov_dir.rglob("*.py"):
     for sub in [".", "benchmark", "ci", "coverage", "lab", "tests"]:
