@@ -727,11 +727,14 @@ class CoverageDataFilesTest(CoverageTest):
         print(debug.get_output())
 
         assert re.search(
-            r"^Closing dbs, force=False: {}\n" +
-            r"Erasing data file '.*\.coverage'\n" +
-            r"Opening data file '.*\.coverage'\n" +
-            r"Initing data file '.*\.coverage'\n" +
-            r"Opening data file '.*\.coverage'\n$",
+            r"^" +
+            r"Closing dbs, force=False: {}\n" +
+            r"Erasing data file '.*\.coverage' \(does not exist\)\n" +
+            r"Opening data file '.*\.coverage' \(does not exist\)\n" +
+            r"Initing data file '.*\.coverage' \(0 bytes, modified [-:. 0-9]+\)\n" +
+            r"Writing \(no-op\) data file '.*\.coverage' \(\d+ bytes, modified [-:. 0-9]+\)\n" +
+            r"Opening data file '.*\.coverage' \(\d+ bytes, modified [-:. 0-9]+\)\n" +
+            r"$",
             debug.get_output(),
         )
 
