@@ -13,12 +13,13 @@ import os.path
 import platform
 import re
 import signal
+import site
 import stat
 import sys
 import textwrap
 
 from pathlib import Path
-from typing import Any
+from typing import Any, Iterable
 
 import pytest
 
@@ -1325,9 +1326,8 @@ class YankedDirectoryTest(CoverageTest):
 class ProcessStartupTest(CoverageTest):
     """Test that we can measure coverage in subprocesses."""
 
-    def setUp(self) -> None:
-        super().setUp()
-
+    def make_main_and_sub(self) -> None:
+        """Create main.py and sub.py."""
         # Main will run sub.py
         self.make_file("main.py", """\
             import os, os.path, sys
@@ -1342,6 +1342,7 @@ class ProcessStartupTest(CoverageTest):
             """)
 
     def test_patch_subprocess(self) -> None:
+        self.make_main_and_sub()
         self.make_file(".coveragerc", """\
             [run]
             patch = subprocess
@@ -1358,6 +1359,7 @@ class ProcessStartupTest(CoverageTest):
         # An existing data file should not be read when a subprocess gets
         # measured automatically.  Create the data file here with bogus data in
         # it.
+        self.make_main_and_sub()
         data = coverage.CoverageData(".mycovdata")
         data.add_lines({os.path.abspath('sub.py'): range(100)})
         data.write()
@@ -1380,6 +1382,7 @@ class ProcessStartupTest(CoverageTest):
 
     def test_subprocess_with_pth_files_and_parallel(self, _create_pth_file: None) -> None:
         # https://github.com/nedbat/coveragepy/issues/492
+        self.make_main_and_sub()
         self.make_file("coverage.ini", """\
             [run]
             parallel = true
@@ -1407,8 +1410,90 @@ class ProcessStartupTest(CoverageTest):
         )
         assert len(data_files) == 1, msg
 
+    def test_subprocess_in_directories(self) -> None:
+        # Bug 2025: patch=subprocess didn't find data files from subdirectory
+        # subprocesses.
+        self.make_file("main.py", """\
+            import subprocess
+            import sys
+            print(subprocess.check_output(
+                [sys.executable, "subproc.py"],
+                cwd="subdir",
+                encoding="utf-8",
+            ))
+            """)
+        self.make_file("subdir/subproc.py", """\
+            with open("readme.txt", encoding="utf-8") as f:
+                print(f.read(), end="")
+            """)
+        self.make_file(".coveragerc", """\
+            [run]
+            patch = subprocess
+            data_file = .covdata
+            """)
+        self.make_file("subdir/readme.txt", "hello")
+        out = self.run_command("coverage run main.py")
+        assert out == "hello\n"
+        self.run_command("coverage combine")
+        data = coverage.CoverageData(".covdata")
+        data.read()
+        assert line_counts(data)["main.py"] == 6
+        assert line_counts(data)["subproc.py"] == 2
+
+    def test_subprocess_gets_nonfile_config(self) -> None:
+        # https://github.com/nedbat/coveragepy/issues/2021
+        self.make_file("subfunctions.py", """\
+            import subprocess, sys
+
+            def f1():
+                print("function 1")
+            def f2():
+                print("function 2")
+
+            functions = [f1, f2]
+
+            cases = sys.argv[1:]
+            if len(cases) > 1:
+                for c in cases:
+                    subprocess.call([sys.executable, __file__, c])
+            else:
+                functions[int(cases[0])]()
+            """)
+        self.make_file(".coveragerc", """\
+            [run]
+            disable_warnings = no-sysmon
+            patch = subprocess
+            """)
+        out = self.run_command("coverage run --branch subfunctions.py 0 1")
+        assert out.endswith("function 1\nfunction 2\n")
+        self.run_command("coverage combine")
+        data = coverage.CoverageData()
+        data.read()
+        assert line_counts(data)["subfunctions.py"] == 11
+
+
+@pytest.fixture
+def _clean_pth_files() -> Iterable[None]:
+    """A fixture to clean up any .pth files we created during the test."""
+    # The execv test needs to make .pth files so that subprocesses will get
+    # measured.  But there's no way for coverage to remove those files because
+    # they need to exist when the new program starts, and there's no
+    # information carried over to clean them automatically.
+    #
+    # So for these tests, we clean them as part of the test suite.
+    pth_files: set[Path] = set()
+    for d in site.getsitepackages():
+        pth_files.update(Path(d).glob("*.pth"))
+
+    try:
+        yield
+    finally:
+        for d in site.getsitepackages():
+            for pth in Path(d).glob("*.pth"):
+                if pth not in pth_files:
+                    pth.unlink()
+
 
-@pytest.mark.skipif(env.METACOV, reason="Can't test subprocess pth file during metacoverage")
 @pytest.mark.skipif(env.WINDOWS, reason="patch=execv isn't supported on Windows")
 @pytest.mark.xdist_group(name="needs_pth")
 class ExecvTest(CoverageTest):
@@ -1420,10 +1505,7 @@ class ExecvTest(CoverageTest):
             ["l", "le", "lp", "lpe", "v", "ve", "vp", "vpe"],
         )]
     )
-    def test_execv_patch(self, fname: str) -> None:
-        if not hasattr(os, fname):
-            pytest.skip(f"This OS doesn't have os.{fname}")
-
+    def test_execv_patch(self, fname: str, _clean_pth_files: None) -> None:
         self.make_file(".coveragerc", """\
             [run]
             patch = subprocess, execv
